import tensorflow as tf
import numpy as np
import ray

# Ray initialization
ray.init()

# Define a simple model within a distribution strategy
def train_distributed_model():
    # Create a MirroredStrategy for distributed training across multiple GPUs
    strategy = tf.distribute.MirroredStrategy()

    # Generate random data
    X_train = np.random.randn(1000, 10)
    y_train = np.random.randn(1000, 1)

    # Define the model inside the strategy scope
    with strategy.scope():
        model = tf.keras.Sequential([
            tf.keras.layers.Dense(64, activation='relu', input_shape=(10,)),
            tf.keras.layers.Dense(1)
        ])

        # Compile the model
        model.compile(optimizer='adam', loss='mse')

        # Train the model
        model.fit(X_train, y_train, epochs=5)

        # Return the model summary
        return model.summary()

# Run the distributed training
if __name__ == "__main__":
    print("Starting distributed training with TensorFlow...")
    train_distributed_model()